@@ -4,13 +4,12 @@
 
 package Net::LDAP::Control::PreRead;
 
-use vars qw(@ISA $VERSION);
 use Net::LDAP::Control;
 
-@ISA = qw(Net::LDAP::Control);
-$VERSION = "0.01";
+our @ISA = qw(Net::LDAP::Control);
+our $VERSION = '0.03';
 
-use Net::LDAP::ASN qw(AttributeDescriptionList prSearchResultEntry);
+use Net::LDAP::ASN qw(AttributeSelection SearchResultEntry);
 use Net::LDAP::Entry;
 use strict;
 
@@ -32,7 +31,7 @@ sub init {
 sub attrs {
   my $self = shift;
 
-  $self->{asn} ||= $AttributeDescriptionList->decode($self->{value});
+  $self->{asn} ||= $AttributeSelection->decode($self->{value});
   if (@_) {
     delete $self->{value};
     return $self->{asn} = [ @_ ];
@@ -47,7 +46,7 @@ sub entry {
   my $entry;
 
   if ($self->{value}) {
-    my $data = $prSearchResultEntry->decode($self->{value});
+    my $data = $SearchResultEntry->decode($self->{value});
 
     $entry = Net::LDAP::Entry->new;
     $entry->decode($data, raw => $opt{raw} || $self->{raw});
@@ -61,7 +60,7 @@ sub value {
 
   exists $self->{value}
     ? $self->{value}
-    : $self->{value} = $AttributeDescriptionList->encode($self->{asn});
+    : $self->{value} = $AttributeSelection->encode($self->{asn});
 }
 
 1;
